import { IpfsCID, MarketplaceTag, QuestionnaireAnswerId, UnixTimestamp } from "../primitives/index.js";
export declare enum EQuestionnaireStatus {
    Available = 0,
    Complete = 1
}
export declare enum EQuestionnaireQuestionType {
    MultipleChoice = 0,
    Location = 1
}
export declare class Questionnaire {
    /**
     * The questionnaire is uniquely identified by it's CID in IPFS. This is the primary key for
     * questionnaires.
     */
    readonly id: IpfsCID;
    readonly marketplaceTag: MarketplaceTag;
    readonly status: EQuestionnaireStatus;
    readonly questions: QuestionnaireQuestion[];
    constructor(
    /**
     * The questionnaire is uniquely identified by it's CID in IPFS. This is the primary key for
     * questionnaires.
     */
    id: IpfsCID, // the location of the questionnaire in IPFS
    marketplaceTag: MarketplaceTag, // The tag that
    status: EQuestionnaireStatus, questions: QuestionnaireQuestion[]);
}
export declare class QuestionnaireWithAnswers extends Questionnaire {
    readonly answers: QuestionnaireAnswer[];
    constructor(id: IpfsCID, marketplaceTag: MarketplaceTag, status: EQuestionnaireStatus, questions: QuestionnaireQuestion[], answers: QuestionnaireAnswer[]);
}
export declare class QuestionnaireQuestion {
    readonly index: number;
    readonly type: EQuestionnaireQuestionType;
    readonly text: string;
    readonly choices: string[] | null;
    constructor(index: number, type: EQuestionnaireQuestionType, text: string, choices: string[] | null);
}
export declare class NewQuestionnaireAnswer {
    readonly questionnaireId: IpfsCID;
    readonly questionIndex: number;
    readonly choice: number;
    readonly measurementDate: UnixTimestamp;
    constructor(questionnaireId: IpfsCID, questionIndex: number, choice: number, measurementDate: UnixTimestamp);
}
export declare class QuestionnaireAnswer extends NewQuestionnaireAnswer {
    readonly id: QuestionnaireAnswerId;
    readonly questionnaireId: IpfsCID;
    readonly questionIndex: number;
    readonly choice: number;
    readonly measurementDate: UnixTimestamp;
    constructor(id: QuestionnaireAnswerId, questionnaireId: IpfsCID, questionIndex: number, choice: number, measurementDate: UnixTimestamp);
}
//# sourceMappingURL=Questionnaire.d.ts.map